@@ -5,10 +5,11 @@ from typing import TYPE_CHECKING, Any, Callable, Dict, List, cast
 from ..util import SUPPORTED_EXTENSIONS, deep_merge, find_files
 from .config import ConfigLoader
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
+    import rcds
+
     from ..project import Project
     from ..project.assets import AssetManagerContext, AssetManagerTransaction
-    import rcds
 
 
 def _strip_scheme(url: str) -> str:
